%%%%%%%%%%%%%%%%%%%%
%6.get_KCob
%	-input: KCScopies.mat, KCcodes.mat
%	-filters:J
%	-output: KCob.mat
%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all

%% LOAD VARS
load('../info/KCcodes_D1_E1-12_F0.5.mat');
load('../info/CScodes_D1_E1-12_F0.5.mat');
load ('../info/CLUSTER.mat');
%load ('../KCvar/KCvar_D1_E1-12_F0.5.mat');
load ('../KCvar/KCvar_devCt_median_sDev_4.mat');
load('../KCScopies/KCScopies.mat');

    %% initialize KCob
    KCob.vals=zeros(length(KCScopies.clusters),length(KCScopies.kos));
    KCob.clusters=KCScopies.clusters;
    KCob.kos=KCScopies.kos;
    KCob.koNames=KCScopies.koNames;
    KCob.koPWs=KCScopies.koPWs;
    KCob.sigVar=zeros(length(KCScopies.clusters),length(KCScopies.kos));
    
    %% set up filters
    ob= strcmp(KCScopies.sampleClass(:,1),'obese') & strcmp(KCScopies.sampleClass(:,2),'healthy');
    le= strcmp(KCScopies.sampleClass(:,1),'lean') & strcmp(KCScopies.sampleClass(:,2),'healthy');
    ibd= strcmp(KCScopies.sampleClass(:,2),'IBD') & strcmp(KCScopies.sampleClass(:,1),'lean');
    he= strcmp(KCScopies.sampleClass(:,2),'healthy') & strcmp(KCScopies.sampleClass(:,1),'lean');
    
    %% get KCob ranksum pval
    for cc=1:length(KCScopies.clusters)
        mask=CScodes(cc,:)';
        if (sum(mask&ob)>=10) && (sum(mask&le)>=10)
            obVals=[];leVals=[];
            for kk=1:length(KCScopies.kos)
                if ~ismember(KCcodes(cc,kk),[-1 -4 -5]) 
                    obVals(:,1)=KCScopies.vals(cc,kk,ob&mask);
                    leVals(:,1)=KCScopies.vals(cc,kk,le&mask);
                    [KCob.vals(cc,kk) h stats]  = ranksum(obVals,leVals);
                    %%% MARK SIG KCs
                    if KCob.vals(cc,kk)<.05
                        KCob.sigVar(cc,kk)=1;
                        [c IX] = sort(KCScopies.vals(cc,kk,:),'ascend');
                        sRank(IX)=1:length(c);
                        KCob.inc(cc,kk) = mean(sRank(ob&mask))>mean(sRank(le&mask));
                    end
                    %%% MARK SIG AND VARIABLE KCs
                    if KCob.vals(cc,kk)<.05 && KCvar.sigVar(cc,kk)
                        KCob.sigVar_var(cc,kk)=1;
                    end
                    
                else
                    KCob.vals(cc,kk)= KCcodes(cc,kk);
                    KCob.inc(cc,kk) = -1;
                end
            end
       %% GET FDR 
         %%%FOR ALL KCs
            fdrCt(cc,1)=sum(my_FDR(KCob.vals(ii,ismember(KCcodes(ii,:),[0 -3]))',.05));
         %%% FOR VARIABLE KCs
            varMask=KCvar.sigVar(cc,:);
            KCob.FDR(cc,varMask) = my_FDR(KCob.vals(cc,varMask)',.05);
        else
            KCob.vals(cc,:)= -2;
            KCob.FDR(cc,:) = 0;
            KCob.inc(cc,:) = -1;
            KCob.sigVar(cc,:)=0;
            KCob.sigVar_var(cc,:)=0;
        end
    end
    
     %% initialize KCibd
    KCibd.vals=zeros(length(KCScopies.clusters),length(KCScopies.kos));
    KCibd.clusters=KCScopies.clusters;
    KCibd.kos=KCScopies.kos;
    KCibd.koNames=KCScopies.koNames;
    KCibd.koPWs=KCScopies.koPWs;
    KCibd.sigVar=zeros(length(KCScopies.clusters),length(KCScopies.kos));
    

%% get KCibd ranksum pval
    for cc=1:length(KCScopies.clusters)
        mask=CScodes(cc,:)';
        if (sum(mask&ibd)>=10) && (sum(mask&he)>=10)
            ibdVals=[];heVals=[];
            for kk=1:length(KCScopies.kos)
                if ~ismember(KCcodes(cc,kk),[-1 -4 -5]) 
                    ibdVals(:,1)=KCScopies.vals(cc,kk,ibd&mask);
                    heVals(:,1)=KCScopies.vals(cc,kk,he&mask);
                    [KCibd.vals(cc,kk) h stats] = ranksum(ibdVals,heVals);
                    if KCibd.vals(cc,kk)<.05
                        KCibd.sigVar(cc,kk)=1;
                        [c IX] = sort(KCScopies.vals(cc,kk,:),'ascend');
                        sRank(IX)=1:length(c);
                        KCibd.inc(cc,kk) = mean(sRank(ob&mask))>mean(sRank(le&mask));
                    end
                    if KCibd.vals(cc,kk)<.05 && KCvar.sigVar(cc,kk)
                        KCibd.sigVar_var(cc,kk)=1;
                    end
                    
                else
                    KCibd.vals(cc,kk)= KCcodes(cc,kk);
                    KCibd.inc(cc,kk) = -1;
                end
            end
       %% GET FDR 
         %%%FOR ALL KCs
            fdrCt(cc,2)=sum(my_FDR(KCibd.vals(ii,ismember(KCcodes(ii,:),[0 -3]))',.05));
         %%% FOR VARIABLE KCs
            varMask=KCvar.sigVar(cc,:);
            KCibd.FDR(cc,varMask) = my_FDR(KCibd.vals(cc,varMask)',.05);
        else
            KCibd.vals(cc,:)= -2;
            KCibd.FDR(cc,:) = 0;
            KCibd.inc(cc,:) = -1;
            KCibd.sigVar(cc,:)=0;
            KCibd.sigVar_var(cc,:)=0;
        end
    end
    %% SAVE KCibd
    %save('KCibd_D1_E1-12_F0.5_v2.mat', 'KCibd');

