# batch job script (LANDSCAPE_metahit_bwa.sh)
#
# Use the bash shell to interpret this job script
#$ -S /bin/bash
#
# Remove one # to send an e-mail to the address 
# specified in .sge_request when this job ends.
#$ -m e
#
# Remove one # to only submit this job to nodes
# that have at least 8GB of RAM free.
#$ -l mem_free=8.0G
#$ -pe serial 4-4
GSITSHOST=`/bin/hostname`
GSITSPWD=`/bin/pwd`
GSITSDATE=`/bin/date`
echo "**** JOB STARTED ON $GSITSHOST AT $GSITSDATE"
echo "**** JOB RUNNING IN $GSITSPWD"
echo "----------------------------------------------"
#shell script to download metahit metagenomic samples as fastq files and BWA them against the LANDSCAPE ref genomes 
LAB=/net/borenstein/vol1
CODE_DIR=$LAB/PROJECTS/StrainVariation_SG/CODE/perl
sampleSet=mockCommunity  #change this to switch between different sample sets: metahit,diabetes,hmp

bedFile=$(echo $(sed -n '6{p;q;}' $CODE_DIR/3_MAP_SAMPLES/$sampleSet\_parameters.txt | grep -Po '\S+$'))
sample=$(cat $CODE_DIR/3_MAP_SAMPLES/$sampleSet\_bwa_batchFiles/$sampleSet\_bwa.$SGE_TASK_ID | grep -Po '^\S+')
bamDir=$(echo $(sed -n '5{p;q;}' $CODE_DIR/3_MAP_SAMPLES/$sampleSet\_parameters.txt | grep -Po '\S+$'))
bamFile=$bamDir/$sample.bam

### FOR WHOLE GENOME ANALYSIS
Programs/samtools-0.1.18/samtools view -hF 4 $bamFile | perl $CODE_DIR/4_GET_MAPPING_RESULTS/STRAINVAR_get_mapped_reads.pl 5 | Programs/samtools-0.1.18/samtools view -bS - | Programs/bedtools-2.17.0/bin/intersectBed -abam stdin -b $bedFile -bed -wao | perl $CODE_DIR/4_GET_MAPPING_RESULTS/STRAINVAR2_get_KCcov.pl > $bamFile.koCov

### FOR 16S ANALYSIS
#bedFile=$(echo 'Projects/SG_SINGLEGENOMES/DATA/landscape/geneInfo/rna_calls/LANDSCAPE.refGenomes.geneInfo_multStrainClusters.n137.16S.BED')
#Programs/samtools-0.1.18/samtools view -hF 4 $bamfile | perl perl/SingleGenomes/LANDSCAPE/TESTBWA2h_get_mapped_reads.pl 5 | Programs/samtools-0.1.18/samtools view -bS - | Programs/bedtools-2.17.0/bin/intersectBed -abam stdin -b $bedFile -bed -wao  | grep 16S > $bamfile.intersectBED.16s
#mv $bamfile.intersectBED.16s $LAB_PATH/PROJECTS/StrainVariation_SG/BWA/bam/16s

## Put the current date into a variable and report it before we exit.
GSITSENDDATE=`/bin/date`
echo "----------------------------------------------"
echo "**** JOB DONE, EXITING 0 AT $GSITSENDDATE"
##
## Exit with return code 0, otherwise the job would exit with the 
## return code of the failed ls command.
exit 0
##
########################################
